@@ -1,7 +1,7 @@
 import time
 
-from com.jivrtt.flow.dist import apply
-from com.jivrtt.flow.flow import BaseIngress, BaseTransformer, BaseEgress, run_flow, BaseSource
+from psf.jivrtt.flow.dist import apply
+from psf.jivrtt.flow.flow import BaseSource, BaseIngress, BaseTransformer, BaseEgress, run_flow
 
 
 class Source(BaseSource):
